#
# spec file for package libcerf
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2014 Christoph Junghans <junghans@votca.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcerf
Version:        2.4
Release:        1.1
Summary:        A library that complex error functions
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://jugit.fz-juelich.de/mlz/libcerf
Source0:        https://jugit.fz-juelich.de/mlz/libcerf/-/archive/v%{version}/%{name}-v%{version}.tar.gz
# PATCH-FIX-OPENSUSE fix_return.patch fix return value in one function
Patch1:         fix_return.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  pkgconfig

%description
libcerf is a self-contained numeric library that provides an efficient and
accurate implementation of complex error functions, along with Dawson,
Faddeeva, and Voigt functions.

%package -n libcerf2
Summary:        A library that provides complex error functions
Group:          Development/Libraries/C and C++

%description -n libcerf2
libcerf is a self-contained numeric library that provides an efficient and
accurate implementation of complex error functions, along with Dawson,
Faddeeva, and Voigt functions.

%package devel
Summary:        Development headers and libraries for libcerf
Group:          Development/Libraries/C and C++
Requires:       libcerf2 = %{version}-%{release}

%description devel
libcerf is a self-contained numeric library that provides an efficient and
accurate implementation of complex error functions, along with Dawson,
Faddeeva, and Voigt functions.

This package contains development headers and libraries for libcerf

%prep
%setup -q -n %{name}-v%{version}
%patch1
# Force cmake to use the paths passed at configure time
sed -i -e 's|lib/pkgconfig/|%{_lib}/pkgconfig/|' CMakeLists.txt
sed -i -e 's|DESTINATION lib|DESTINATION %{_lib}|' lib/CMakeLists.txt
sed -i -e 's|${prefix}/lib|@LIB_INSTALL_DIR@|' libcerf.pc.in

%build
%cmake -DCMAKE_SKIP_RPATH=OFF -DPORTABLE=ON
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/doc/cerf/* %{buildroot}%{_docdir}/%{name}
%fdupes %{buildroot}%{_prefix}

%post -n libcerf2 -p /sbin/ldconfig
%postun -n libcerf2 -p /sbin/ldconfig

%check
%ctest

%files -n libcerf2
%license LICENSE
%{_libdir}/libcerf.so.*

%files devel
%{_includedir}/*.h
%{_libdir}/libcerf.so
%{_libdir}/pkgconfig/libcerf.pc
%{_mandir}/man3/*
%{_docdir}/%{name}
%{_libdir}/cmake/cerf

%changelog
* Wed Oct 11 2023 ming li <mli@suse.com>
- update to 2.4:
  * CMake: runtime destination corrected (bin, not lib)
  * CMake: removed option PORTABLE and compiler flag -march (unavailable on some architectures)
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3:
  * Add test coverage for erfcx, dawson, im_w_of_x (against
    nearby complex and status quo)
  * Avoid some divisions in function voigt
  * Accelerate lookup in erfcx, im_w_of_x (avoid long switch,
    contributed by Alexander Kleinsorge)
* Fri Dec  2 2022 Dirk Müller <dmueller@suse.com>
- update to 2.2:
  - No longer raise underflow error in w_of_z for large real arg (contributed by Ethan Merritt)
  - In test suite, confound zero with values close to underflow
  - Remove some invisible files that had slipped in accidentally (noticed by Christoph Junghans)
  - Windows binary now built with Visual Studio 17 2022
* Thu Jul 14 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1:
  - provide cerfConfig.cmake (contributed by Lori A. Burns and Christoph Junghans)
  - libcerf.pc: remove hard-coded lib/
  - version number incremented to overcome upstream problems with withdrawn release 2.0
- drop 2.patch (upstream)
* Tue Dec 14 2021 Christoph Junghans <junghans@votca.org>
- Fix test execution
* Sat Dec  4 2021 Christoph Junghans <junghans@votca.org>
- Bump v1.17
  - Correct pkgconfig installation directory (use GNU install
    dirs, install to LIBDIR/pkgconfig
- added 2.patch from upstream PR#2 to add cmake export
- added fix_return.patch to fix missing return value
* Wed Nov 22 2017 junghans@votca.org
- Bump to v1.5:
  * rm unused inline function (detected by clang-1.3., reported by Luke Benes)
* Tue Nov 21 2017 idonmez@suse.com
- Fix source url
* Fri Oct  9 2015 junghans@votca.org
- version bump to 1.4, details from http://apps.jcns.fz-juelich.de/src/libcerf/CHANGELOG
  * HTML version of man pages no longer installs to man/html.
  * More concise man pages.
  * Delete a few unused include's.
  * Autotools script corrected (suggestions by Christoph Junghans)
- added %%check section
* Fri Jul 24 2015 werner@suse.de
- Use official upstream URL
* Mon Jul 14 2014 junghans@votca.org
- initial commit
